"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = huskyLintStagedConfigGenerator;

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

var _fsExtra = _interopRequireDefault(require("fs-extra"));

var _ansiColors = _interopRequireDefault(require("ansi-colors"));

var _pkgManager = _interopRequireDefault(require("../utils/pkgManager"));

function huskyLintStagedConfigGenerator(_x) {
  return _huskyLintStagedConfigGenerator.apply(this, arguments);
}

function _huskyLintStagedConfigGenerator() {
  _huskyLintStagedConfigGenerator = (0, _asyncToGenerator2["default"])( /*#__PURE__*/_regenerator["default"].mark(function _callee(installedPackages) {
    var hasPrettier, hasEslint, hasStylelint;
    return _regenerator["default"].wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            console.log(_ansiColors["default"].blue('\nConfiguring Husky & Lint-Staged 🔨 🔨'));
            _context.next = 3;
            return _pkgManager["default"].install(['husky', 'lint-staged', 'is-ci', 'cross-env']);

          case 3:
            _context.next = 5;
            return _pkgManager["default"].runCommand('npx husky install');

          case 5:
            _context.next = 7;
            return _pkgManager["default"].runCommand('npm set-script prepare "is-ci || husky install" ');

          case 7:
            // lint-staged configuration
            hasPrettier = installedPackages.includes('Prettier');
            hasEslint = installedPackages.includes('Eslint');
            hasStylelint = installedPackages.includes('Stylelint');
            _context.next = 12;
            return _fsExtra["default"].writeJSON('.lintstagedrc.json', {
              '*.{js,js,ts,tsx}': [hasEslint && 'eslint --fix --max-warnings 0', hasPrettier && 'prettier --write', 'cross-env CI=true npm run test --if-present  -- --findRelatedTests --bail'].filter(Boolean),
              '*.{css,scss,sass}': [hasStylelint && 'stylelint --fix --max-warnings 0', hasPrettier && 'prettier --write'].filter(Boolean),
              '*.{html,json,md,mdx,yml,yaml}': [hasPrettier && 'prettier --write'].filter(Boolean)
            }, {
              spaces: 2
            });

          case 12:
            _context.next = 14;
            return _pkgManager["default"].runCommand('npx husky set .husky/pre-commit "npx lint-staged"');

          case 14:
            if (!installedPackages.includes('Commitlint')) {
              _context.next = 17;
              break;
            }

            _context.next = 17;
            return _pkgManager["default"].runCommand('npx husky set .husky/commit-msg "npx --no -- commitlint --edit $1"');

          case 17:
            if (!installedPackages.includes('Commitizen')) {
              _context.next = 20;
              break;
            }

            _context.next = 20;
            return _pkgManager["default"].runCommand('npx husky set .husky/prepare-commit-msg "exec < /dev/tty && git cz --hook || true"');

          case 20:
            console.log(_ansiColors["default"].bold.blue('Husky & Lint-Staged successfully configured 🎉 🎉\n'));
            if (hasEslint || hasStylelint || hasPrettier) console.log(_ansiColors["default"].bold.cyan("We added scripts for ".concat([hasEslint && 'eslint', hasStylelint && 'stylelint', hasPrettier && 'prettier'].filter(Boolean).join(', '), " [check] & [fix] to use locally and in CI\n")));

          case 22:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  }));
  return _huskyLintStagedConfigGenerator.apply(this, arguments);
}