"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = prettierConfigGenerator;

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

var _path = _interopRequireDefault(require("path"));

var _fsExtra = _interopRequireDefault(require("fs-extra"));

var _ansiColors = _interopRequireDefault(require("ansi-colors"));

var _pkgManager = _interopRequireDefault(require("../utils/pkgManager"));

var _constants = _interopRequireDefault(require("../constants"));

function prettierConfigGenerator() {
  return _prettierConfigGenerator.apply(this, arguments);
}

function _prettierConfigGenerator() {
  _prettierConfigGenerator = (0, _asyncToGenerator2["default"])( /*#__PURE__*/_regenerator["default"].mark(function _callee() {
    var file, _yield$Promise$all, _yield$Promise$all2, hasEslintConfiguration, hasStylelintConfiguration;

    return _regenerator["default"].wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            console.log(_ansiColors["default"].blue('\nConfiguring Prettier 🔨 🔨'));
            _context.next = 3;
            return _pkgManager["default"].install('prettier');

          case 3:
            _context.next = 5;
            return _fsExtra["default"].readJSON(_path["default"].join(_constants["default"].configFolder, 'prettier.json'));

          case 5:
            file = _context.sent;
            _context.next = 8;
            return _fsExtra["default"].writeJSON('.prettierrc.json', file, {
              spaces: 2
            });

          case 8:
            _context.next = 10;
            return Promise.all([_fsExtra["default"].pathExists('.eslintrc.json'), _fsExtra["default"].pathExists('.stylelintrc.json')]);

          case 10:
            _yield$Promise$all = _context.sent;
            _yield$Promise$all2 = (0, _slicedToArray2["default"])(_yield$Promise$all, 2);
            hasEslintConfiguration = _yield$Promise$all2[0];
            hasStylelintConfiguration = _yield$Promise$all2[1];

            if (!hasEslintConfiguration) {
              _context.next = 17;
              break;
            }

            _context.next = 17;
            return integratePrettierWithEslint();

          case 17:
            if (!hasStylelintConfiguration) {
              _context.next = 20;
              break;
            }

            _context.next = 20;
            return integreatePrettierWithStylelint();

          case 20:
            _context.next = 22;
            return addScripts();

          case 22:
            console.log(_ansiColors["default"].blue('Prettier successfully configured 🎉 🎉'));

          case 23:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  }));
  return _prettierConfigGenerator.apply(this, arguments);
}

function integratePrettierWithEslint() {
  return _integratePrettierWithEslint.apply(this, arguments);
}

function _integratePrettierWithEslint() {
  _integratePrettierWithEslint = (0, _asyncToGenerator2["default"])( /*#__PURE__*/_regenerator["default"].mark(function _callee2() {
    var eslintConfig;
    return _regenerator["default"].wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.next = 2;
            return _pkgManager["default"].install(['eslint-config-prettier', 'eslint-plugin-prettier']);

          case 2:
            _context2.next = 4;
            return _fsExtra["default"].readJSON('.eslintrc.json');

          case 4:
            eslintConfig = _context2.sent;
            // extend eslint-config-prettier
            if (!eslintConfig["extends"].some(function (config) {
              return config === 'prettier';
            })) eslintConfig["extends"].push('prettier'); // add eslint-plugin-prettier

            if (!eslintConfig.plugins.some(function (config) {
              return config === 'prettier';
            })) eslintConfig.plugins.push('prettier');
            eslintConfig.rules['prettier/prettier'] = 'error';
            _context2.next = 10;
            return _fsExtra["default"].writeJSON('.eslintrc.json', eslintConfig, {
              spaces: 2
            });

          case 10:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  }));
  return _integratePrettierWithEslint.apply(this, arguments);
}

function integreatePrettierWithStylelint() {
  return _integreatePrettierWithStylelint.apply(this, arguments);
}

function _integreatePrettierWithStylelint() {
  _integreatePrettierWithStylelint = (0, _asyncToGenerator2["default"])( /*#__PURE__*/_regenerator["default"].mark(function _callee3() {
    var stylelintConfig;
    return _regenerator["default"].wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            _context3.next = 2;
            return _pkgManager["default"].install(['stylelint-config-prettier', 'stylelint-prettier']);

          case 2:
            _context3.next = 4;
            return _fsExtra["default"].readJSON('.stylelintrc.json');

          case 4:
            stylelintConfig = _context3.sent;
            if (!stylelintConfig["extends"].includes('stylelint-config-prettier')) stylelintConfig["extends"].push('stylelint-config-prettier');
            stylelintConfig.plugins = stylelintConfig.plugins ? stylelintConfig.plugins.concat('stylelint-prettier') : ['stylelint-prettier'];
            stylelintConfig.rules['prettier/prettier'] = true;
            _context3.next = 10;
            return _fsExtra["default"].writeJSON('.stylelintrc.json', stylelintConfig, {
              spaces: 2
            });

          case 10:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  }));
  return _integreatePrettierWithStylelint.apply(this, arguments);
}

function addScripts() {
  return _addScripts.apply(this, arguments);
}

function _addScripts() {
  _addScripts = (0, _asyncToGenerator2["default"])( /*#__PURE__*/_regenerator["default"].mark(function _callee4() {
    return _regenerator["default"].wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            _context4.next = 2;
            return Promise.all([_pkgManager["default"].runCommand('npm set-script prettier:check "prettier . --check --ignore-unknown"'), _pkgManager["default"].runCommand('npm set-script prettier:fix "prettier . --write --ignore-unknown"')]);

          case 2:
          case "end":
            return _context4.stop();
        }
      }
    }, _callee4);
  }));
  return _addScripts.apply(this, arguments);
}